# xtools
[![Version on Pypi](https://img.shields.io/pypi/v/xtools.svg?label=PyPI)](https://pypi.org/project/coveralls/)
[![Coverage Status](https://coveralls.io/repos/github/bfontaine/xtools/badge.svg?branch=master)](https://coveralls.io/github/bfontaine/xtools?branch=master)

**xtools** is a Python wrapper around [XTools][]’ API.

[XTools]: https://xtools.readthedocs.io/en/stable/index.html

Note this project is not affiliated with nor endorsed by XTools.

## Install

    pip install xtools

### Requirements

Python 3.5+.

## Usage

[Read the docs](https://python-xtools.readthedocs.io/en/latest/).